@@ -2,6 +2,7 @@ from ccxt.base.types import Entry
 
 
 class ImplicitAPI:
+    fund_v1_private_get_account_balance = fundV1PrivateGetAccountBalance = Entry('account/balance', ['fund', 'v1', 'private'], 'GET', {'cost': 1})
     spot_v1_public_get_server_time = spotV1PublicGetServerTime = Entry('server/time', ['spot', 'v1', 'public'], 'GET', {'cost': 1})
     spot_v1_public_get_common_symbols = spotV1PublicGetCommonSymbols = Entry('common/symbols', ['spot', 'v1', 'public'], 'GET', {'cost': 1})
     spot_v1_public_get_market_trades = spotV1PublicGetMarketTrades = Entry('market/trades', ['spot', 'v1', 'public'], 'GET', {'cost': 1})
@@ -16,6 +17,9 @@ class ImplicitAPI:
     spot_v1_private_get_trade_mytrades = spotV1PrivateGetTradeMyTrades = Entry('trade/myTrades', ['spot', 'v1', 'private'], 'GET', {'cost': 2})
     spot_v1_private_get_user_commissionrate = spotV1PrivateGetUserCommissionRate = Entry('user/commissionRate', ['spot', 'v1', 'private'], 'GET', {'cost': 5})
     spot_v1_private_get_account_balance = spotV1PrivateGetAccountBalance = Entry('account/balance', ['spot', 'v1', 'private'], 'GET', {'cost': 2})
+    spot_v1_private_get_oco_orderlist = spotV1PrivateGetOcoOrderList = Entry('oco/orderList', ['spot', 'v1', 'private'], 'GET', {'cost': 5})
+    spot_v1_private_get_oco_openorderlist = spotV1PrivateGetOcoOpenOrderList = Entry('oco/openOrderList', ['spot', 'v1', 'private'], 'GET', {'cost': 5})
+    spot_v1_private_get_oco_historyorderlist = spotV1PrivateGetOcoHistoryOrderList = Entry('oco/historyOrderList', ['spot', 'v1', 'private'], 'GET', {'cost': 5})
     spot_v1_private_post_trade_order = spotV1PrivatePostTradeOrder = Entry('trade/order', ['spot', 'v1', 'private'], 'POST', {'cost': 2})
     spot_v1_private_post_trade_cancel = spotV1PrivatePostTradeCancel = Entry('trade/cancel', ['spot', 'v1', 'private'], 'POST', {'cost': 2})
     spot_v1_private_post_trade_batchorders = spotV1PrivatePostTradeBatchOrders = Entry('trade/batchOrders', ['spot', 'v1', 'private'], 'POST', {'cost': 5})
@@ -23,6 +27,8 @@ class ImplicitAPI:
     spot_v1_private_post_trade_cancelorders = spotV1PrivatePostTradeCancelOrders = Entry('trade/cancelOrders', ['spot', 'v1', 'private'], 'POST', {'cost': 5})
     spot_v1_private_post_trade_cancelopenorders = spotV1PrivatePostTradeCancelOpenOrders = Entry('trade/cancelOpenOrders', ['spot', 'v1', 'private'], 'POST', {'cost': 5})
     spot_v1_private_post_trade_cancelallafter = spotV1PrivatePostTradeCancelAllAfter = Entry('trade/cancelAllAfter', ['spot', 'v1', 'private'], 'POST', {'cost': 5})
+    spot_v1_private_post_oco_order = spotV1PrivatePostOcoOrder = Entry('oco/order', ['spot', 'v1', 'private'], 'POST', {'cost': 5})
+    spot_v1_private_post_oco_cancel = spotV1PrivatePostOcoCancel = Entry('oco/cancel', ['spot', 'v1', 'private'], 'POST', {'cost': 5})
     spot_v2_public_get_market_depth = spotV2PublicGetMarketDepth = Entry('market/depth', ['spot', 'v2', 'public'], 'GET', {'cost': 1})
     spot_v2_public_get_market_kline = spotV2PublicGetMarketKline = Entry('market/kline', ['spot', 'v2', 'public'], 'GET', {'cost': 1})
     spot_v3_private_get_get_asset_transfer = spotV3PrivateGetGetAssetTransfer = Entry('get/asset/transfer', ['spot', 'v3', 'private'], 'GET', {'cost': 1})
@@ -34,6 +40,7 @@ class ImplicitAPI:
     swap_v1_public_get_market_historicaltrades = swapV1PublicGetMarketHistoricalTrades = Entry('market/historicalTrades', ['swap', 'v1', 'public'], 'GET', {'cost': 1})
     swap_v1_public_get_market_markpriceklines = swapV1PublicGetMarketMarkPriceKlines = Entry('market/markPriceKlines', ['swap', 'v1', 'public'], 'GET', {'cost': 1})
     swap_v1_public_get_trade_multiassetsrules = swapV1PublicGetTradeMultiAssetsRules = Entry('trade/multiAssetsRules', ['swap', 'v1', 'public'], 'GET', {'cost': 1})
+    swap_v1_public_get_tradingrules = swapV1PublicGetTradingRules = Entry('tradingRules', ['swap', 'v1', 'public'], 'GET', {'cost': 1})
     swap_v1_private_get_positionside_dual = swapV1PrivateGetPositionSideDual = Entry('positionSide/dual', ['swap', 'v1', 'private'], 'GET', {'cost': 5})
     swap_v1_private_get_trade_batchcancelreplace = swapV1PrivateGetTradeBatchCancelReplace = Entry('trade/batchCancelReplace', ['swap', 'v1', 'private'], 'GET', {'cost': 5})
     swap_v1_private_get_trade_fullorder = swapV1PrivateGetTradeFullOrder = Entry('trade/fullOrder', ['swap', 'v1', 'private'], 'GET', {'cost': 2})
@@ -53,6 +60,8 @@ class ImplicitAPI:
     swap_v1_private_post_twap_order = swapV1PrivatePostTwapOrder = Entry('twap/order', ['swap', 'v1', 'private'], 'POST', {'cost': 5})
     swap_v1_private_post_twap_cancelorder = swapV1PrivatePostTwapCancelOrder = Entry('twap/cancelOrder', ['swap', 'v1', 'private'], 'POST', {'cost': 5})
     swap_v1_private_post_trade_assetmode = swapV1PrivatePostTradeAssetMode = Entry('trade/assetMode', ['swap', 'v1', 'private'], 'POST', {'cost': 5})
+    swap_v1_private_post_trade_reverse = swapV1PrivatePostTradeReverse = Entry('trade/reverse', ['swap', 'v1', 'private'], 'POST', {'cost': 5})
+    swap_v1_private_post_trade_autoaddmargin = swapV1PrivatePostTradeAutoAddMargin = Entry('trade/autoAddMargin', ['swap', 'v1', 'private'], 'POST', {'cost': 5})
     swap_v2_public_get_server_time = swapV2PublicGetServerTime = Entry('server/time', ['swap', 'v2', 'public'], 'GET', {'cost': 1})
     swap_v2_public_get_quote_contracts = swapV2PublicGetQuoteContracts = Entry('quote/contracts', ['swap', 'v2', 'public'], 'GET', {'cost': 1})
     swap_v2_public_get_quote_price = swapV2PublicGetQuotePrice = Entry('quote/price', ['swap', 'v2', 'public'], 'GET', {'cost': 1})
@@ -91,6 +100,7 @@ class ImplicitAPI:
     swap_v2_private_delete_trade_batchorders = swapV2PrivateDeleteTradeBatchOrders = Entry('trade/batchOrders', ['swap', 'v2', 'private'], 'DELETE', {'cost': 2})
     swap_v2_private_delete_trade_allopenorders = swapV2PrivateDeleteTradeAllOpenOrders = Entry('trade/allOpenOrders', ['swap', 'v2', 'private'], 'DELETE', {'cost': 2})
     swap_v3_public_get_quote_klines = swapV3PublicGetQuoteKlines = Entry('quote/klines', ['swap', 'v3', 'public'], 'GET', {'cost': 1})
+    swap_v3_private_get_user_balance = swapV3PrivateGetUserBalance = Entry('user/balance', ['swap', 'v3', 'private'], 'GET', {'cost': 2})
     cswap_v1_public_get_market_contracts = cswapV1PublicGetMarketContracts = Entry('market/contracts', ['cswap', 'v1', 'public'], 'GET', {'cost': 1})
     cswap_v1_public_get_market_premiumindex = cswapV1PublicGetMarketPremiumIndex = Entry('market/premiumIndex', ['cswap', 'v1', 'public'], 'GET', {'cost': 1})
     cswap_v1_public_get_market_openinterest = cswapV1PublicGetMarketOpenInterest = Entry('market/openInterest', ['cswap', 'v1', 'public'], 'GET', {'cost': 1})
@@ -140,6 +150,7 @@ class ImplicitAPI:
     account_v1_private_get_uid = accountV1PrivateGetUid = Entry('uid', ['account', 'v1', 'private'], 'GET', {'cost': 1})
     account_v1_private_get_apikey_query = accountV1PrivateGetApiKeyQuery = Entry('apiKey/query', ['account', 'v1', 'private'], 'GET', {'cost': 2})
     account_v1_private_get_account_apipermissions = accountV1PrivateGetAccountApiPermissions = Entry('account/apiPermissions', ['account', 'v1', 'private'], 'GET', {'cost': 5})
+    account_v1_private_get_allaccountbalance = accountV1PrivateGetAllAccountBalance = Entry('allAccountBalance', ['account', 'v1', 'private'], 'GET', {'cost': 2})
     account_v1_private_post_innertransfer_authorizesubaccount = accountV1PrivatePostInnerTransferAuthorizeSubAccount = Entry('innerTransfer/authorizeSubAccount', ['account', 'v1', 'private'], 'POST', {'cost': 1})
     account_transfer_v1_private_get_subaccount_asset_transferhistory = accountTransferV1PrivateGetSubAccountAssetTransferHistory = Entry('subAccount/asset/transferHistory', ['account', 'transfer', 'v1', 'private'], 'GET', {'cost': 1})
     account_transfer_v1_private_post_subaccount_transferasset_supportcoins = accountTransferV1PrivatePostSubAccountTransferAssetSupportCoins = Entry('subAccount/transferAsset/supportCoins', ['account', 'transfer', 'v1', 'private'], 'POST', {'cost': 1})
@@ -152,6 +163,17 @@ class ImplicitAPI:
     copytrading_v1_private_post_swap_trace_settpsl = copyTradingV1PrivatePostSwapTraceSetTPSL = Entry('swap/trace/setTPSL', ['copyTrading', 'v1', 'private'], 'POST', {'cost': 2})
     copytrading_v1_private_post_spot_trader_sellorder = copyTradingV1PrivatePostSpotTraderSellOrder = Entry('spot/trader/sellOrder', ['copyTrading', 'v1', 'private'], 'POST', {'cost': 10})
     api_v3_private_get_asset_transfer = apiV3PrivateGetAssetTransfer = Entry('asset/transfer', ['api', 'v3', 'private'], 'GET', {'cost': 1})
+    api_v3_private_get_asset_transferrecord = apiV3PrivateGetAssetTransferRecord = Entry('asset/transferRecord', ['api', 'v3', 'private'], 'GET', {'cost': 5})
     api_v3_private_get_capital_deposit_hisrec = apiV3PrivateGetCapitalDepositHisrec = Entry('capital/deposit/hisrec', ['api', 'v3', 'private'], 'GET', {'cost': 1})
     api_v3_private_get_capital_withdraw_history = apiV3PrivateGetCapitalWithdrawHistory = Entry('capital/withdraw/history', ['api', 'v3', 'private'], 'GET', {'cost': 1})
     api_v3_private_post_post_asset_transfer = apiV3PrivatePostPostAssetTransfer = Entry('post/asset/transfer', ['api', 'v3', 'private'], 'POST', {'cost': 1})
+    api_asset_v1_private_post_transfer = apiAssetV1PrivatePostTransfer = Entry('transfer', ['api', 'asset', 'v1', 'private'], 'POST', {'cost': 5})
+    api_asset_v1_public_get_transfer_supportcoins = apiAssetV1PublicGetTransferSupportCoins = Entry('transfer/supportCoins', ['api', 'asset', 'v1', 'public'], 'GET', {'cost': 5})
+    agent_v1_private_get_account_inviteaccountlist = agentV1PrivateGetAccountInviteAccountList = Entry('account/inviteAccountList', ['agent', 'v1', 'private'], 'GET', {'cost': 5})
+    agent_v1_private_get_reward_commissiondatalist = agentV1PrivateGetRewardCommissionDataList = Entry('reward/commissionDataList', ['agent', 'v1', 'private'], 'GET', {'cost': 5})
+    agent_v1_private_get_account_inviterelationcheck = agentV1PrivateGetAccountInviteRelationCheck = Entry('account/inviteRelationCheck', ['agent', 'v1', 'private'], 'GET', {'cost': 5})
+    agent_v1_private_get_asset_depositdetaillist = agentV1PrivateGetAssetDepositDetailList = Entry('asset/depositDetailList', ['agent', 'v1', 'private'], 'GET', {'cost': 5})
+    agent_v1_private_get_reward_third_commissiondatalist = agentV1PrivateGetRewardThirdCommissionDataList = Entry('reward/third/commissionDataList', ['agent', 'v1', 'private'], 'GET', {'cost': 5})
+    agent_v1_private_get_asset_partnerdata = agentV1PrivateGetAssetPartnerData = Entry('asset/partnerData', ['agent', 'v1', 'private'], 'GET', {'cost': 5})
+    agent_v1_private_get_commissiondatalist_referralcode = agentV1PrivateGetCommissionDataListReferralCode = Entry('commissionDataList/referralCode', ['agent', 'v1', 'private'], 'GET', {'cost': 5})
+    agent_v1_private_get_account_superiorcheck = agentV1PrivateGetAccountSuperiorCheck = Entry('account/superiorCheck', ['agent', 'v1', 'private'], 'GET', {'cost': 5})
