@@ -48,6 +48,7 @@ class ImplicitAPI:
     public_get_v5_spot_lever_token_info = publicGetV5SpotLeverTokenInfo = Entry('v5/spot-lever-token/info', 'public', 'GET', {'cost': 5})
     public_get_v5_spot_lever_token_reference = publicGetV5SpotLeverTokenReference = Entry('v5/spot-lever-token/reference', 'public', 'GET', {'cost': 5})
     public_get_v5_spot_margin_trade_data = publicGetV5SpotMarginTradeData = Entry('v5/spot-margin-trade/data', 'public', 'GET', {'cost': 5})
+    public_get_v5_spot_margin_trade_collateral = publicGetV5SpotMarginTradeCollateral = Entry('v5/spot-margin-trade/collateral', 'public', 'GET', {'cost': 5})
     public_get_v5_spot_cross_margin_trade_data = publicGetV5SpotCrossMarginTradeData = Entry('v5/spot-cross-margin-trade/data', 'public', 'GET', {'cost': 5})
     public_get_v5_spot_cross_margin_trade_pledge_token = publicGetV5SpotCrossMarginTradePledgeToken = Entry('v5/spot-cross-margin-trade/pledge-token', 'public', 'GET', {'cost': 5})
     public_get_v5_spot_cross_margin_trade_borrow_token = publicGetV5SpotCrossMarginTradeBorrowToken = Entry('v5/spot-cross-margin-trade/borrow-token', 'public', 'GET', {'cost': 5})
@@ -55,6 +56,7 @@ class ImplicitAPI:
     public_get_v5_crypto_loan_loanable_data = publicGetV5CryptoLoanLoanableData = Entry('v5/crypto-loan/loanable-data', 'public', 'GET', {'cost': 5})
     public_get_v5_ins_loan_product_infos = publicGetV5InsLoanProductInfos = Entry('v5/ins-loan/product-infos', 'public', 'GET', {'cost': 5})
     public_get_v5_ins_loan_ensure_tokens_convert = publicGetV5InsLoanEnsureTokensConvert = Entry('v5/ins-loan/ensure-tokens-convert', 'public', 'GET', {'cost': 5})
+    public_get_v5_earn_product = publicGetV5EarnProduct = Entry('v5/earn/product', 'public', 'GET', {'cost': 5})
     private_get_v5_market_instruments_info = privateGetV5MarketInstrumentsInfo = Entry('v5/market/instruments-info', 'private', 'GET', {'cost': 5})
     private_get_v2_private_wallet_fund_records = privateGetV2PrivateWalletFundRecords = Entry('v2/private/wallet/fund/records', 'private', 'GET', {'cost': 25})
     private_get_spot_v3_private_order = privateGetSpotV3PrivateOrder = Entry('spot/v3/private/order', 'private', 'GET', {'cost': 2.5})
@@ -126,6 +128,7 @@ class ImplicitAPI:
     private_get_v5_pre_upgrade_asset_settlement_record = privateGetV5PreUpgradeAssetSettlementRecord = Entry('v5/pre-upgrade/asset/settlement-record', 'private', 'GET', {'cost': 5})
     private_get_v5_account_wallet_balance = privateGetV5AccountWalletBalance = Entry('v5/account/wallet-balance', 'private', 'GET', {'cost': 1})
     private_get_v5_account_borrow_history = privateGetV5AccountBorrowHistory = Entry('v5/account/borrow-history', 'private', 'GET', {'cost': 1})
+    private_get_v5_account_instruments_info = privateGetV5AccountInstrumentsInfo = Entry('v5/account/instruments-info', 'private', 'GET', {'cost': 1})
     private_get_v5_account_collateral_info = privateGetV5AccountCollateralInfo = Entry('v5/account/collateral-info', 'private', 'GET', {'cost': 1})
     private_get_v5_asset_coin_greeks = privateGetV5AssetCoinGreeks = Entry('v5/asset/coin-greeks', 'private', 'GET', {'cost': 1})
     private_get_v5_account_fee_rate = privateGetV5AccountFeeRate = Entry('v5/account/fee-rate', 'private', 'GET', {'cost': 10})
@@ -155,6 +158,7 @@ class ImplicitAPI:
     private_get_v5_asset_deposit_query_address = privateGetV5AssetDepositQueryAddress = Entry('v5/asset/deposit/query-address', 'private', 'GET', {'cost': 10})
     private_get_v5_asset_deposit_query_sub_member_address = privateGetV5AssetDepositQuerySubMemberAddress = Entry('v5/asset/deposit/query-sub-member-address', 'private', 'GET', {'cost': 10})
     private_get_v5_asset_coin_query_info = privateGetV5AssetCoinQueryInfo = Entry('v5/asset/coin/query-info', 'private', 'GET', {'cost': 28})
+    private_get_v5_asset_withdraw_query_address = privateGetV5AssetWithdrawQueryAddress = Entry('v5/asset/withdraw/query-address', 'private', 'GET', {'cost': 10})
     private_get_v5_asset_withdraw_query_record = privateGetV5AssetWithdrawQueryRecord = Entry('v5/asset/withdraw/query-record', 'private', 'GET', {'cost': 10})
     private_get_v5_asset_withdraw_withdrawable_amount = privateGetV5AssetWithdrawWithdrawableAmount = Entry('v5/asset/withdraw/withdrawable-amount', 'private', 'GET', {'cost': 5})
     private_get_v5_asset_withdraw_vasp_list = privateGetV5AssetWithdrawVaspList = Entry('v5/asset/withdraw/vasp/list', 'private', 'GET', {'cost': 5})
@@ -169,6 +173,10 @@ class ImplicitAPI:
     private_get_v5_spot_lever_token_order_record = privateGetV5SpotLeverTokenOrderRecord = Entry('v5/spot-lever-token/order-record', 'private', 'GET', {'cost': 1})
     private_get_v5_spot_margin_trade_interest_rate_history = privateGetV5SpotMarginTradeInterestRateHistory = Entry('v5/spot-margin-trade/interest-rate-history', 'private', 'GET', {'cost': 5})
     private_get_v5_spot_margin_trade_state = privateGetV5SpotMarginTradeState = Entry('v5/spot-margin-trade/state', 'private', 'GET', {'cost': 5})
+    private_get_v5_spot_margin_trade_max_borrowable = privateGetV5SpotMarginTradeMaxBorrowable = Entry('v5/spot-margin-trade/max-borrowable', 'private', 'GET', {'cost': 5})
+    private_get_v5_spot_margin_trade_position_tiers = privateGetV5SpotMarginTradePositionTiers = Entry('v5/spot-margin-trade/position-tiers', 'private', 'GET', {'cost': 5})
+    private_get_v5_spot_margin_trade_coinstate = privateGetV5SpotMarginTradeCoinstate = Entry('v5/spot-margin-trade/coinstate', 'private', 'GET', {'cost': 5})
+    private_get_v5_spot_margin_trade_repayment_available_amount = privateGetV5SpotMarginTradeRepaymentAvailableAmount = Entry('v5/spot-margin-trade/repayment-available-amount', 'private', 'GET', {'cost': 5})
     private_get_v5_spot_cross_margin_trade_loan_info = privateGetV5SpotCrossMarginTradeLoanInfo = Entry('v5/spot-cross-margin-trade/loan-info', 'private', 'GET', {'cost': 1})
     private_get_v5_spot_cross_margin_trade_account = privateGetV5SpotCrossMarginTradeAccount = Entry('v5/spot-cross-margin-trade/account', 'private', 'GET', {'cost': 1})
     private_get_v5_spot_cross_margin_trade_orders = privateGetV5SpotCrossMarginTradeOrders = Entry('v5/spot-cross-margin-trade/orders', 'private', 'GET', {'cost': 1})
@@ -191,6 +199,8 @@ class ImplicitAPI:
     private_get_v5_broker_earnings_info = privateGetV5BrokerEarningsInfo = Entry('v5/broker/earnings-info', 'private', 'GET', {'cost': 5})
     private_get_v5_broker_account_info = privateGetV5BrokerAccountInfo = Entry('v5/broker/account-info', 'private', 'GET', {'cost': 5})
     private_get_v5_broker_asset_query_sub_member_deposit_record = privateGetV5BrokerAssetQuerySubMemberDepositRecord = Entry('v5/broker/asset/query-sub-member-deposit-record', 'private', 'GET', {'cost': 10})
+    private_get_v5_earn_order = privateGetV5EarnOrder = Entry('v5/earn/order', 'private', 'GET', {'cost': 5})
+    private_get_v5_earn_position = privateGetV5EarnPosition = Entry('v5/earn/position', 'private', 'GET', {'cost': 5})
     private_post_spot_v3_private_order = privatePostSpotV3PrivateOrder = Entry('spot/v3/private/order', 'private', 'POST', {'cost': 2.5})
     private_post_spot_v3_private_cancel_order = privatePostSpotV3PrivateCancelOrder = Entry('spot/v3/private/cancel-order', 'private', 'POST', {'cost': 2.5})
     private_post_spot_v3_private_cancel_orders = privatePostSpotV3PrivateCancelOrders = Entry('spot/v3/private/cancel-orders', 'private', 'POST', {'cost': 2.5})
@@ -271,6 +281,8 @@ class ImplicitAPI:
     private_post_v5_account_set_hedging_mode = privatePostV5AccountSetHedgingMode = Entry('v5/account/set-hedging-mode', 'private', 'POST', {'cost': 5})
     private_post_v5_account_mmp_modify = privatePostV5AccountMmpModify = Entry('v5/account/mmp-modify', 'private', 'POST', {'cost': 5})
     private_post_v5_account_mmp_reset = privatePostV5AccountMmpReset = Entry('v5/account/mmp-reset', 'private', 'POST', {'cost': 5})
+    private_post_v5_account_borrow = privatePostV5AccountBorrow = Entry('v5/account/borrow', 'private', 'POST', {'cost': 5})
+    private_post_v5_account_repay = privatePostV5AccountRepay = Entry('v5/account/repay', 'private', 'POST', {'cost': 5})
     private_post_v5_asset_exchange_quote_apply = privatePostV5AssetExchangeQuoteApply = Entry('v5/asset/exchange/quote-apply', 'private', 'POST', {'cost': 1})
     private_post_v5_asset_exchange_convert_execute = privatePostV5AssetExchangeConvertExecute = Entry('v5/asset/exchange/convert-execute', 'private', 'POST', {'cost': 1})
     private_post_v5_asset_transfer_inter_transfer = privatePostV5AssetTransferInterTransfer = Entry('v5/asset/transfer/inter-transfer', 'private', 'POST', {'cost': 50})
@@ -306,3 +318,4 @@ class ImplicitAPI:
     private_post_v5_broker_award_info = privatePostV5BrokerAwardInfo = Entry('v5/broker/award/info', 'private', 'POST', {'cost': 5})
     private_post_v5_broker_award_distribute_award = privatePostV5BrokerAwardDistributeAward = Entry('v5/broker/award/distribute-award', 'private', 'POST', {'cost': 5})
     private_post_v5_broker_award_distribution_record = privatePostV5BrokerAwardDistributionRecord = Entry('v5/broker/award/distribution-record', 'private', 'POST', {'cost': 5})
+    private_post_v5_earn_place_order = privatePostV5EarnPlaceOrder = Entry('v5/earn/place-order', 'private', 'POST', {'cost': 5})
