@@ -20,6 +20,8 @@ class ImplicitAPI:
     public_get_mark_price_symbol_current = publicGetMarkPriceSymbolCurrent = Entry('mark-price/{symbol}/current', 'public', 'GET', {'cost': 3})
     public_get_mark_price_all_symbols = publicGetMarkPriceAllSymbols = Entry('mark-price/all-symbols', 'public', 'GET', {'cost': 3})
     public_get_margin_config = publicGetMarginConfig = Entry('margin/config', 'public', 'GET', {'cost': 25})
+    public_get_announcements = publicGetAnnouncements = Entry('announcements', 'public', 'GET', {'cost': 20})
+    public_get_margin_collateralratio = publicGetMarginCollateralRatio = Entry('margin/collateralRatio', 'public', 'GET', {'cost': 10})
     public_post_bullet_public = publicPostBulletPublic = Entry('bullet-public', 'public', 'POST', {'cost': 15})
     private_get_user_info = privateGetUserInfo = Entry('user-info', 'private', 'GET', {'cost': 30})
     private_get_accounts = privateGetAccounts = Entry('accounts', 'private', 'GET', {'cost': 7.5})
@@ -48,6 +50,7 @@ class ImplicitAPI:
     private_get_market_orderbook_level_level = privateGetMarketOrderbookLevelLevel = Entry('market/orderbook/level{level}', 'private', 'GET', {'cost': 3})
     private_get_market_orderbook_level2 = privateGetMarketOrderbookLevel2 = Entry('market/orderbook/level2', 'private', 'GET', {'cost': 3})
     private_get_market_orderbook_level3 = privateGetMarketOrderbookLevel3 = Entry('market/orderbook/level3', 'private', 'GET', {'cost': 3})
+    private_get_hf_accounts_opened = privateGetHfAccountsOpened = Entry('hf/accounts/opened', 'private', 'GET', {'cost': 2})
     private_get_hf_orders_active = privateGetHfOrdersActive = Entry('hf/orders/active', 'private', 'GET', {'cost': 2})
     private_get_hf_orders_active_symbols = privateGetHfOrdersActiveSymbols = Entry('hf/orders/active/symbols', 'private', 'GET', {'cost': 2})
     private_get_hf_margin_order_active_symbols = privateGetHfMarginOrderActiveSymbols = Entry('hf/margin/order/active/symbols', 'private', 'GET', {'cost': 2})
@@ -88,6 +91,9 @@ class ImplicitAPI:
     private_get_redeem_orders = privateGetRedeemOrders = Entry('redeem/orders', 'private', 'GET', {'cost': 10})
     private_get_purchase_orders = privateGetPurchaseOrders = Entry('purchase/orders', 'private', 'GET', {'cost': 10})
     private_get_broker_api_rebase_download = privateGetBrokerApiRebaseDownload = Entry('broker/api/rebase/download', 'private', 'GET', {'cost': 3})
+    private_get_broker_querymycommission = privateGetBrokerQueryMyCommission = Entry('broker/queryMyCommission', 'private', 'GET', {'cost': 3})
+    private_get_broker_queryuser = privateGetBrokerQueryUser = Entry('broker/queryUser', 'private', 'GET', {'cost': 3})
+    private_get_broker_querydetailbyuid = privateGetBrokerQueryDetailByUid = Entry('broker/queryDetailByUid', 'private', 'GET', {'cost': 3})
     private_get_migrate_user_account_status = privateGetMigrateUserAccountStatus = Entry('migrate/user/account/status', 'private', 'GET', {'cost': 3})
     private_get_affiliate_inviter_statistics = privateGetAffiliateInviterStatistics = Entry('affiliate/inviter/statistics', 'private', 'GET', {'cost': 30})
     private_post_sub_user_created = privatePostSubUserCreated = Entry('sub/user/created', 'private', 'POST', {'cost': 22.5})
@@ -123,6 +129,7 @@ class ImplicitAPI:
     private_post_lend_purchase_update = privatePostLendPurchaseUpdate = Entry('lend/purchase/update', 'private', 'POST', {'cost': 10})
     private_post_bullet_private = privatePostBulletPrivate = Entry('bullet-private', 'private', 'POST', {'cost': 10})
     private_post_position_update_user_leverage = privatePostPositionUpdateUserLeverage = Entry('position/update-user-leverage', 'private', 'POST', {'cost': 5})
+    private_post_deposit_address_create = privatePostDepositAddressCreate = Entry('deposit-address/create', 'private', 'POST', {'cost': 20})
     private_delete_sub_api_key = privateDeleteSubApiKey = Entry('sub/api-key', 'private', 'DELETE', {'cost': 45})
     private_delete_withdrawals_withdrawalid = privateDeleteWithdrawalsWithdrawalId = Entry('withdrawals/{withdrawalId}', 'private', 'DELETE', {'cost': 30})
     private_delete_hf_orders_orderid = privateDeleteHfOrdersOrderId = Entry('hf/orders/{orderId}', 'private', 'DELETE', {'cost': 1})
@@ -180,6 +187,8 @@ class ImplicitAPI:
     futuresprivate_get_margin_maxwithdrawmargin = futuresPrivateGetMarginMaxWithdrawMargin = Entry('margin/maxWithdrawMargin', 'futuresPrivate', 'GET', {'cost': 15})
     futuresprivate_get_contracts_risk_limit_symbol = futuresPrivateGetContractsRiskLimitSymbol = Entry('contracts/risk-limit/{symbol}', 'futuresPrivate', 'GET', {'cost': 7.5})
     futuresprivate_get_funding_history = futuresPrivateGetFundingHistory = Entry('funding-history', 'futuresPrivate', 'GET', {'cost': 7.5})
+    futuresprivate_get_copy_trade_futures_get_max_open_size = futuresPrivateGetCopyTradeFuturesGetMaxOpenSize = Entry('copy-trade/futures/get-max-open-size', 'futuresPrivate', 'GET', {'cost': 6})
+    futuresprivate_get_copy_trade_futures_position_margin_max_withdraw_margin = futuresPrivateGetCopyTradeFuturesPositionMarginMaxWithdrawMargin = Entry('copy-trade/futures/position/margin/max-withdraw-margin', 'futuresPrivate', 'GET', {'cost': 15})
     futuresprivate_post_transfer_out = futuresPrivatePostTransferOut = Entry('transfer-out', 'futuresPrivate', 'POST', {'cost': 30})
     futuresprivate_post_transfer_in = futuresPrivatePostTransferIn = Entry('transfer-in', 'futuresPrivate', 'POST', {'cost': 30})
     futuresprivate_post_orders = futuresPrivatePostOrders = Entry('orders', 'futuresPrivate', 'POST', {'cost': 3})
@@ -189,11 +198,24 @@ class ImplicitAPI:
     futuresprivate_post_margin_withdrawmargin = futuresPrivatePostMarginWithdrawMargin = Entry('margin/withdrawMargin', 'futuresPrivate', 'POST', {'cost': 15})
     futuresprivate_post_position_margin_deposit_margin = futuresPrivatePostPositionMarginDepositMargin = Entry('position/margin/deposit-margin', 'futuresPrivate', 'POST', {'cost': 6})
     futuresprivate_post_position_risk_limit_level_change = futuresPrivatePostPositionRiskLimitLevelChange = Entry('position/risk-limit-level/change', 'futuresPrivate', 'POST', {'cost': 6})
+    futuresprivate_post_copy_trade_futures_orders = futuresPrivatePostCopyTradeFuturesOrders = Entry('copy-trade/futures/orders', 'futuresPrivate', 'POST', {'cost': 3})
+    futuresprivate_post_copy_trade_futures_orders_test = futuresPrivatePostCopyTradeFuturesOrdersTest = Entry('copy-trade/futures/orders/test', 'futuresPrivate', 'POST', {'cost': 3})
+    futuresprivate_post_copy_trade_futures_st_orders = futuresPrivatePostCopyTradeFuturesStOrders = Entry('copy-trade/futures/st-orders', 'futuresPrivate', 'POST', {'cost': 3})
+    futuresprivate_post_copy_trade_futures_position_margin_deposit_margin = futuresPrivatePostCopyTradeFuturesPositionMarginDepositMargin = Entry('copy-trade/futures/position/margin/deposit-margin', 'futuresPrivate', 'POST', {'cost': 6})
+    futuresprivate_post_copy_trade_futures_position_margin_withdraw_margin = futuresPrivatePostCopyTradeFuturesPositionMarginWithdrawMargin = Entry('copy-trade/futures/position/margin/withdraw-margin', 'futuresPrivate', 'POST', {'cost': 15})
+    futuresprivate_post_copy_trade_futures_position_risk_limit_level_change = futuresPrivatePostCopyTradeFuturesPositionRiskLimitLevelChange = Entry('copy-trade/futures/position/risk-limit-level/change', 'futuresPrivate', 'POST', {'cost': 3})
+    futuresprivate_post_copy_trade_futures_position_margin_auto_deposit_status = futuresPrivatePostCopyTradeFuturesPositionMarginAutoDepositStatus = Entry('copy-trade/futures/position/margin/auto-deposit-status', 'futuresPrivate', 'POST', {'cost': 6})
+    futuresprivate_post_copy_trade_futures_position_changemarginmode = futuresPrivatePostCopyTradeFuturesPositionChangeMarginMode = Entry('copy-trade/futures/position/changeMarginMode', 'futuresPrivate', 'POST', {'cost': 3})
+    futuresprivate_post_copy_trade_futures_position_changecrossuserleverage = futuresPrivatePostCopyTradeFuturesPositionChangeCrossUserLeverage = Entry('copy-trade/futures/position/changeCrossUserLeverage', 'futuresPrivate', 'POST', {'cost': 3})
+    futuresprivate_post_copy_trade_getcrossmodemarginrequirement = futuresPrivatePostCopyTradeGetCrossModeMarginRequirement = Entry('copy-trade/getCrossModeMarginRequirement', 'futuresPrivate', 'POST', {'cost': 4.5})
+    futuresprivate_post_copy_trade_position_switchpositionmode = futuresPrivatePostCopyTradePositionSwitchPositionMode = Entry('copy-trade/position/switchPositionMode', 'futuresPrivate', 'POST', {'cost': 3})
     futuresprivate_post_bullet_private = futuresPrivatePostBulletPrivate = Entry('bullet-private', 'futuresPrivate', 'POST', {'cost': 15})
     futuresprivate_delete_orders_orderid = futuresPrivateDeleteOrdersOrderId = Entry('orders/{orderId}', 'futuresPrivate', 'DELETE', {'cost': 1.5})
     futuresprivate_delete_orders_client_order_clientoid = futuresPrivateDeleteOrdersClientOrderClientOid = Entry('orders/client-order/{clientOid}', 'futuresPrivate', 'DELETE', {'cost': 1.5})
     futuresprivate_delete_orders = futuresPrivateDeleteOrders = Entry('orders', 'futuresPrivate', 'DELETE', {'cost': 45})
     futuresprivate_delete_stoporders = futuresPrivateDeleteStopOrders = Entry('stopOrders', 'futuresPrivate', 'DELETE', {'cost': 22.5})
+    futuresprivate_delete_copy_trade_futures_orders = futuresPrivateDeleteCopyTradeFuturesOrders = Entry('copy-trade/futures/orders', 'futuresPrivate', 'DELETE', {'cost': 1.5})
+    futuresprivate_delete_copy_trade_futures_orders_client_order = futuresPrivateDeleteCopyTradeFuturesOrdersClientOrder = Entry('copy-trade/futures/orders/client-order', 'futuresPrivate', 'DELETE', {'cost': 1.5})
     webexchange_get_currency_currency_chain_info = webExchangeGetCurrencyCurrencyChainInfo = Entry('currency/currency/chain-info', 'webExchange', 'GET', {'cost': 1})
     broker_get_broker_nd_info = brokerGetBrokerNdInfo = Entry('broker/nd/info', 'broker', 'GET', {'cost': 2})
     broker_get_broker_nd_account = brokerGetBrokerNdAccount = Entry('broker/nd/account', 'broker', 'GET', {'cost': 2})
@@ -219,3 +241,14 @@ class ImplicitAPI:
     earn_get_earn_eth_staking_products = earnGetEarnEthStakingProducts = Entry('earn/eth-staking/products', 'earn', 'GET', {'cost': 7.5})
     earn_post_earn_orders = earnPostEarnOrders = Entry('earn/orders', 'earn', 'POST', {'cost': 7.5})
     earn_delete_earn_orders = earnDeleteEarnOrders = Entry('earn/orders', 'earn', 'DELETE', {'cost': 7.5})
+    uta_get_market_announcement = utaGetMarketAnnouncement = Entry('market/announcement', 'uta', 'GET', {'cost': 20})
+    uta_get_market_currency = utaGetMarketCurrency = Entry('market/currency', 'uta', 'GET', {'cost': 3})
+    uta_get_market_instrument = utaGetMarketInstrument = Entry('market/instrument', 'uta', 'GET', {'cost': 4})
+    uta_get_market_ticker = utaGetMarketTicker = Entry('market/ticker', 'uta', 'GET', {'cost': 15})
+    uta_get_market_orderbook = utaGetMarketOrderbook = Entry('market/orderbook', 'uta', 'GET', {'cost': 3})
+    uta_get_market_trade = utaGetMarketTrade = Entry('market/trade', 'uta', 'GET', {'cost': 3})
+    uta_get_market_kline = utaGetMarketKline = Entry('market/kline', 'uta', 'GET', {'cost': 3})
+    uta_get_market_funding_rate = utaGetMarketFundingRate = Entry('market/funding-rate', 'uta', 'GET', {'cost': 2})
+    uta_get_market_funding_rate_history = utaGetMarketFundingRateHistory = Entry('market/funding-rate-history', 'uta', 'GET', {'cost': 5})
+    uta_get_market_cross_config = utaGetMarketCrossConfig = Entry('market/cross-config', 'uta', 'GET', {'cost': 25})
+    uta_get_market_server_status = utaGetMarketServerStatus = Entry('market/server/status', 'uta', 'GET', {'cost': 3})
