@@ -4,7 +4,7 @@
 
 # ----------------------------------------------------------------------------
 
-__version__ = '4.5.6'
+__version__ = '4.5.15'
 
 # ----------------------------------------------------------------------------
 
@@ -59,6 +59,7 @@ from ccxt.base.errors import error_hierarchy                          # noqa: F4
 
 from ccxt.pro.alpaca import alpaca                                        # noqa: F401
 from ccxt.pro.apex import apex                                            # noqa: F401
+from ccxt.pro.arkham import arkham                                        # noqa: F401
 from ccxt.pro.ascendex import ascendex                                    # noqa: F401
 from ccxt.pro.backpack import backpack                                    # noqa: F401
 from ccxt.pro.bequant import bequant                                      # noqa: F401
@@ -114,7 +115,6 @@ from ccxt.pro.mexc import mexc                                            # noqa
 from ccxt.pro.modetrade import modetrade                                  # noqa: F401
 from ccxt.pro.myokx import myokx                                          # noqa: F401
 from ccxt.pro.ndax import ndax                                            # noqa: F401
-from ccxt.pro.okcoin import okcoin                                        # noqa: F401
 from ccxt.pro.okx import okx                                              # noqa: F401
 from ccxt.pro.okxus import okxus                                          # noqa: F401
 from ccxt.pro.onetrading import onetrading                                # noqa: F401
@@ -134,6 +134,7 @@ from ccxt.pro.xt import xt                                                # noqa
 exchanges = [
     'alpaca',
     'apex',
+    'arkham',
     'ascendex',
     'backpack',
     'bequant',
@@ -189,7 +190,6 @@ exchanges = [
     'modetrade',
     'myokx',
     'ndax',
-    'okcoin',
     'okx',
     'okxus',
     'onetrading',
